@@ -1,12 +1,9 @@
 from django.conf import settings
 from django.db import models, connection, transaction
-from django.db.models.signals import post_delete
-from django.dispatch import receiver
 from django.core.management import call_command
-from django.utils.functional import lazy
 from tenant_schemas.postgresql_backend.base import _check_identifier
 from tenant_schemas.signals import post_schema_sync
-from tenant_schemas.utils import django_is_in_test_mode, schema_exists, get_tenant_model
+from tenant_schemas.utils import django_is_in_test_mode, schema_exists
 from tenant_schemas.utils import get_public_schema_name
 
 
@@ -36,19 +33,25 @@ class TenantMixin(models.Model):
             raise Exception("Can't update tenant outside it's own schema or the public schema. Current schema is %s."
                             % connection.get_schema())
 
-        super(TenantMixin, self).save(*args, **kwargs)
-
         if is_new and self.auto_create_schema:
             self.create_schema(check_if_exists=True, verbosity=verbosity)
             post_schema_sync.send(sender=TenantMixin, tenant=self)
 
-        transaction.commit_unless_managed()
+        super(TenantMixin, self).save(*args, **kwargs)
 
     def delete(self, *args, **kwargs):
+        """
+        Drops the schema related to the tenant instance. Just drop the schema if the parent
+        class model has the attribute auto_drop_schema set to True.
+        """
         if connection.get_schema() not in (self.schema_name, get_public_schema_name()):
             raise Exception("Can't delete tenant outside it's own schema or the public schema. Current schema is %s."
                             % connection.get_schema())
 
+        if schema_exists(self.schema_name) and self.auto_drop_schema:
+            cursor = connection.cursor()
+            cursor.execute('DROP SCHEMA %s CASCADE' % self.schema_name)
+
         super(TenantMixin, self).delete(*args, **kwargs)
 
     def create_schema(self, check_if_exists=False, sync_schema=True, verbosity=1):
@@ -83,16 +86,4 @@ class TenantMixin(models.Model):
                 call_command('migrate_schemas', fake=True, schema_name=self.schema_name, verbosity=verbosity)
 
         connection.set_schema_to_public()
-
         return True
-
-@receiver(post_delete, sender=lazy(get_tenant_model))
-def drop_schema(sender, instance, **kwargs):
-    """
-    Called in post_delete signal.
-    Drops the schema related to the tenant instance. Just drop the schema if the parent
-    class model has the attribute auto_drop_schema set to True.
-    """
-    if schema_exists(instance.schema_name) and instance.auto_drop_schema:
-        cursor = connection.cursor()
-        cursor.execute('DROP SCHEMA %s CASCADE' % instance.schema_name)
